@@ -5,7 +5,7 @@ __author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo
 __docformat__ = 'plaintext'
 
 import logging
-logger = logging.getLogger('PyConBrasil')
+logger = logging.getLogger('Products.PyConBrasil')
 logger.debug('Installing Product')
 
 try:
@@ -25,12 +25,15 @@ from Products.Archetypes import listTypes
 from Products.Archetypes.utils import capitalize
 
 import os, os.path
+from zope.i18nmessageid import MessageFactory as BaseMessageFactory
+MessageFactory = BaseMessageFactory('Products.PyConBrasil')
 
 from Products.PyConBrasil.config import *
 
 def initialize(context):
 
     import Inscricoes
+    import InscricaoCorporativa
     import Inscricao
     import Trabalho
     import Treinamento
